@@ -500,7 +500,7 @@ xnee_replay_main_loop(xnee_data *xd, int read_mode)
 		  xnee_verbose((xd, "READ A XINPUT EVENT SLAVE\n")); 
 		  
 		  xnee_replay_update_dev_ctr(xd, 
-					     (xindata.u.xievent.type-xnee_get_xinput_event_base(xd->fake)));
+					     xindata.u.xievent.type);
 		  
 		  ret = xnee_replay_synchronize (xd);
 		  if (ret != XNEE_OK)
